@@ -370,6 +370,15 @@ for field in fields:
 
         print("\n\n")
 
+    if 'photometry_id' in conf['run_steps']:
+
+        script = os.path.join(pipeline_path, 'steps', 'photometry_id.py')
+        cmd = f'python3 {script} {field} {conf_file}'
+        ut.printlog(cmd, log_field_file)
+        os.system(cmd)
+
+        print("\n\n")
+
     if 'photometry_master' in conf['run_steps']:
 
         script = os.path.join(pipeline_path, 'steps', 'photometry_master.py')
