@@ -228,40 +228,6 @@ def get_external_calib_zero_points():
 
 get_external_calib_zero_points()
 
-# ***************************************************
-#    Copy zp offset to be applied
-# ***************************************************
-
-def copy_offset_zp_file():
-    """
-    Copies the offset zp file to be applied for the field
-    """
-
-    if conf['offset_to_splus_refcalib'].lower()[-4:] != 'none':
-
-        print("")
-        ut.printlog(('********** '
-                     'Copying offset .zp file '
-                     '**********'),
-                    log_file)
-        print("")
-
-        save_name = f'offset_refcalib.zp'
-        save_file = os.path.join(external_cal_path, save_name)
-
-        if not os.path.exists(save_file):
-
-            cmd = f"cp {conf['offset_to_splus_refcalib']} {save_file}"
-            ut.printlog(cmd, log_file)
-            os.system(cmd)
-
-            ut.printlog(f"Created file {save_file}", log_file)
-
-        else:
-            ut.printlog(f"ZP file {save_name} already exists", log_file)
-
-
-copy_offset_zp_file()
 
 # ***************************************************
 #    Add offset to S-PLUS reference calibration
@@ -273,12 +239,13 @@ def add_offset_to_splus_reference_calibration():
     Adds offset to S-PLUS reference calibration
     """
 
-    print("")
-    ut.printlog(('********** '
-                 'Adding offset to S-PLUS reference calibration '
-                 '**********'),
-                 log_file)
-    print("")
+    if conf['offset_include_after'].lower() == "external":
+        print("")
+        ut.printlog(('********** '
+                     'Adding offset to S-PLUS reference calibration '
+                     '**********'),
+                     log_file)
+        print("")
 
     external_zp_name = f"{field}_external_tmp.zp"
     external_zp_file = os.path.join(external_cal_path, external_zp_name)
@@ -288,14 +255,14 @@ def add_offset_to_splus_reference_calibration():
 
     if not os.path.exists(save_file):
 
-        if conf['offset_to_splus_refcalib'].lower()[-4:] == 'none':
-            cmd = f"cp {external_zp_file} {save_file}"
-            os.system(cmd)
-
-        else:
+        if conf['offset_include_after'].lower() == "external":
             offset_zp_name = f'offset_refcalib.zp'
             offset_zp_file = os.path.join(external_cal_path, offset_zp_name)
 
+            cmd = f"cp {conf['offset_to_splus_refcalib']} {offset_zp_file}"
+            ut.printlog(cmd, log_file)
+            os.system(cmd)
+
             zp_file_list = [external_zp_file, offset_zp_file]
 
             filters = []
@@ -308,6 +275,10 @@ def add_offset_to_splus_reference_calibration():
                       filters=filters,
                       inst_zp=0)
 
+        else:
+            cmd = f"cp {external_zp_file} {save_file}"
+            os.system(cmd)
+
         ut.printlog(f"Created file {save_file}", log_file)
 
     else:
