@@ -130,7 +130,7 @@ def copy_splus_master_photometry():
     catalog_file = os.path.join(photometry_path, calib_phot, 'master',
                                 catalog_name)
 
-    save_name = f'{field}_SPLUS_{calib_phot}.fits'
+    save_name = f'{field}_SPLUS_{calib_phot}_tmp.fits'
     save_file = os.path.join(crossmatch_path, save_name)
 
     if not os.path.exists(save_file):
@@ -140,11 +140,51 @@ def copy_splus_master_photometry():
         os.system(cmd)
 
     else:
-        ut.printlog(f"Catalog {catalog_file} already exists", log_file)
+        ut.printlog(f"Catalog {save_file} already exists", log_file)
 
 
 copy_splus_master_photometry()
 
+
+# ***************************************************
+#    Add photometry offset
+# ***************************************************
+
+def adding_instrumental_offset():
+
+    calib_phot = conf['calibration_photometry']
+
+    catalog_name = f'{field}_SPLUS_{calib_phot}_tmp.fits'
+    catalog_file = os.path.join(crossmatch_path, catalog_name)
+
+    save_name = f'{field}_SPLUS_{calib_phot}.fits'
+    save_file = os.path.join(crossmatch_path, save_name)
+
+    if not os.path.exists(save_file):
+        if conf["offset_inst_mag"].lower != "none":
+
+            print("")
+            ut.printlog(('********** '
+                         'Adding instrumental photometry offset '
+                         '**********'),
+                        log_file)
+            print("")
+
+            ut.add_inst_offset(catalog     = catalog_file,
+                               offset_file = conf["offset_inst_mag"],
+                               save_file   = save_file)
+
+        else:
+            cmd = f"cp {catalog_file} {save_file}"
+            ut.printlog(cmd, log_file)
+            os.system(cmd)
+
+    else:
+        ut.printlog(f"Catalog {save_file} already exists", log_file)
+
+
+adding_instrumental_offset()
+
 # ***************************************************
 #    Download reference catalogs
 # ***************************************************
