@@ -233,10 +233,10 @@ def create_master_photometry_dual():
             catalog_file = os.path.join(dual_master_path, catalog_name)
 
             cmd += f"ifmt{i+1}=fits in{i+1}={catalog_file} "
-            cmd += f"values{i+1}=NUMBER join{i+1}=always "
+            cmd += f"values{i+1}='RA DEC' join{i+1}=always "
 
         cmd += f"out={save_file} ofmt=fits "
-        cmd += f"matcher=exact multimode=group "
+        cmd += f"matcher=sky params=1 multimode=group "
 
         ut.printlog(cmd, log_file)
         os.system(cmd)
